@@ -1,9 +1,9 @@
 package Complete::Sah;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-02-12'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Complete-Sah'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -163,8 +163,8 @@ sub complete_from_schema {
                     push @$summaries, undef;
                 }
             }
-            $static++;
-            return; # from eval. there should not be any other value
+            #$static++;
+            #return; # from eval. there should not be any other value
         }
         if ($type eq 'any') {
             # because currently Data::Sah::Normalize doesn't recursively
@@ -358,7 +358,7 @@ Complete::Sah - Sah-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.004 of Complete::Sah (from Perl distribution Complete-Sah), released on 2020-02-12.
+This document describes version 0.005 of Complete::Sah (from Perl distribution Complete-Sah), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
